pub struct GlyphFlags(pub hb_glyph_flags_t);Expand description
A set of flags that may be set during shaping on each glyph.
Tuple Fields
0: hb_glyph_flags_tImplementations
Sourceimpl GlyphFlags
impl GlyphFlags
Sourcepub fn unsafe_to_break(&self) -> bool
pub fn unsafe_to_break(&self) -> bool
If true, indicates that if input text is broken at the beginning of
the cluster this glyph is part of, then both sides need to be re-shaped,
as the result might be different. On the flip side, it means that when
this function returns false, then it’s safe to break the glyph-run at
the beginning of this cluster, and the two sides represent the exact
same result one would get if breaking input text at the beginning of
this cluster and shaping the two sides separately. This can be used to
optimize paragraph layout, by avoiding re-shaping of each line after
line-breaking, or limiting the reshaping to a small piece around the
breaking point only.